#[repr(u8)]enum PanicTriggered {
WasKernelPanicTriggered = 1,
WasRustPanicTriggered = 2,
}Expand description
Enum helper to not have to write the raw bitshifts on every PANIC_TRIGGERED interaction
#[repr(u8)]enum PanicTriggered {
WasKernelPanicTriggered = 1,
WasRustPanicTriggered = 2,
}Enum helper to not have to write the raw bitshifts on every PANIC_TRIGGERED interaction